==> owncloud-9.0.3.tgz: owncloud/apps/encryption/l10n/pt_BR.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Senha da chave de recuperação em falta",
    "Please repeat the recovery key password" : "Por favor, repita a senha da chave de recuperação",
    "Repeated recovery key password does not match the provided recovery key password" : "A senha repetidas da chave de valorização não corresponde a senha da chave de recuperação prevista",
    "Recovery key successfully enabled" : "Recuperação de chave habilitada com sucesso",
    "Could not enable recovery key. Please check your recovery key password!" : "Impossível habilitar recuperação de chave. Por favor verifique sua senha para recuperação de chave!",
    "Recovery key successfully disabled" : "Recuperação de chave desabilitada com sucesso",
    "Could not disable recovery key. Please check your recovery key password!" : "Impossível desabilitar recuperação de chave. Por favor verifique sua senha para recuperação de chave!",
    "Missing parameters" : "Parâmetros que faltam",
    "Please provide the old recovery password" : "Por favor, forneça a antiga senha de recuperação",
    "Please provide a new recovery password" : "Por favor, forneça a nova senha de recuperação",
    "Please repeat the new recovery password" : "Por favor, repita a nova senha de recuperação",
    "Password successfully changed." : "Senha alterada com sucesso.",
    "Could not change the password. Maybe the old password was not correct." : "Não foi possível alterar a senha. Talvez a senha antiga não estava correta.",
    "Recovery Key disabled" : "Recuperação de chave desativada",
    "Recovery Key enabled" : "Recuperar Chave habilitada",
    "Could not enable the recovery key, please try again or contact your administrator" : "Não foi possível habilitar a chave recuperada, por favor tente novamente ou entre em contato com seu administrador",
    "Could not update the private key password." : "Não foi possível atualizar a senha da chave privada.",
    "The old password was not correct, please try again." : "A senha antiga não estava correta, por favor, tente novamente.",
    "The current log-in password was not correct, please try again." : "A senha atual do log-in não estava correta, por favor, tente novamente.",
    "Private key password successfully updated." : "Senha de chave privada atualizada com sucesso.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "Você precisa migrar suas chaves de criptografia a partir da antiga criptografia (ownCloud <= 8,0) para a nova. Por favor, execute 'occ encryption:migrate' ou contate o seu administrador",
    "Invalid private key for Encryption App. Please update your private key password in your personal settings to recover access to your encrypted files." : "Chave do App de Criptografia é inválida. Por favor, atualize sua senha de chave privada em suas configurações pessoais para recuperar o acesso a seus arquivos criptografados.",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "App de criptografia está ativado, mas as chaves não estão inicializadas, por favor log-out e faça login novamente",
    "Encryption App is enabled and ready" : "Aplicativo de criptografia está ativado e pronto",
    "Bad Signature" : "Assinatura Ruim",
    "Missing Signature" : "Faltando Assinatura",
    "one-time password for server-side-encryption" : "senha de uso único para criptografia-lado-servidor",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Este arquivo não pode ser decriptado, provavelmente este é um arquivo compartilhado. Por favor peça ao dono do arquivo para compartilha-lo com você.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Não é possível ler este arquivo, provavelmente este é um arquivo compartilhado. Por favor, pergunte o dono do arquivo para recompartilhar o arquivo com você.",
    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'ownCloud basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n" : "Olá,\n\nO administrador habilitou criptografia-lado-servidor. Os seus arquivos foram criptografados usando a senha '%s'.\n\nPor favor faça o login para a interface da Web, vá para a seção 'ownCloud módulo de criptografia básico' das suas definições pessoais e atualize sua senha de criptografia, inserindo esta senha no campo 'senha antiga de log-in' e sua atual senha-de-login.\n\n",
    "The share will expire on %s." : "O compartilhamento irá expirar em %s.",
    "Cheers!" : "Saudações!",
    "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"ownCloud basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "Olá,<br><br>o administrador habilitou criptografia-lado-servidor. Os seus arquivos foram criptografados usando a senha <strong>%s</strong>.<br><br>Por favor faça o login para a interface da Web, vá para a seção 'ownCloud módulo de criptografia básico' das suas definições pessoais e atualize sua senha de criptografia, inserindo esta senha no campo 'senha antiga de log-in' e sua atual senha-de-login..<br><br>",
    "Encrypt the home storage" : "Criptografar a pasta de armazenamento home",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Ativar essa opção de criptografia para todos os arquivos armazenados no armazenamento principal, caso contrário, apenas arquivos no armazenamento externo serão criptografados",
    "Enable recovery key" : "Habilitar recuperação de chave",
    "Disable recovery key" : "Dasabilitar chave de recuperação",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "A chave de recuperação é uma chave de encriptação extra que é utilizada para encriptar arquivos. Ela permite a recuperação de arquivos de um usuário esquecer sua senha.",
    "Recovery key password" : "Senha da chave de recuperação",
    "Repeat recovery key password" : "Repita senha da chave de recuperação",
    "Change recovery key password:" : "Mudar a senha da chave de recuperação:",
    "Old recovery key password" : "Senha da chave de recuperação antiga",
    "New recovery key password" : "Nova senha da chave de recuperação",
    "Repeat new recovery key password" : "Repita a nova senha da chave de recuperação",
    "Change Password" : "Trocar Senha",
    "ownCloud basic encryption module" : "Modo de criptografia básico ownCloud",
    "Your private key password no longer matches your log-in password." : "A sua senha de chave privada não corresponde a sua senha de login.",
    "Set your old private key password to your current log-in password:" : "Defina a sua antiga senha da chave privada para sua senha de login atual:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Se você não se lembra de sua antiga senha você pode pedir ao administrador que recupere seus arquivos.",
    "Old log-in password" : "Senha antiga de login",
    "Current log-in password" : "Senha de login atual",
    "Update Private Key Password" : "Atualizar Senha de Chave Privada",
    "Enable password recovery:" : "Habilitar recuperação de senha:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Habilitar essa opção vai permitir que você obtenha novamente acesso aos seus arquivos encriptados em caso de perda de senha",
    "Enabled" : "Habilitado",
    "Disabled" : "Desabilitado"
},
"nplurals=2; plural=(n > 1);");

==> owncloud-10.0.7.tgz: owncloud/apps/encryption/l10n/pt_BR.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Senha da chave de recuperação em falta",
    "Please repeat the recovery key password" : "Por favor, repita a senha da chave de recuperação",
    "Repeated recovery key password does not match the provided recovery key password" : "A senha repetidas da chave de valorização não corresponde a senha da chave de recuperação prevista",
    "Recovery key successfully enabled" : "Recuperação de chave habilitada com sucesso",
    "Could not enable recovery key. Please check your recovery key password!" : "Impossível habilitar recuperação de chave. Por favor verifique sua senha para recuperação de chave!",
    "Recovery key successfully disabled" : "Recuperação de chave desabilitada com sucesso",
    "Could not disable recovery key. Please check your recovery key password!" : "Impossível desabilitar recuperação de chave. Por favor verifique sua senha para recuperação de chave!",
    "Missing parameters" : "Parâmetros que faltam",
    "Please provide the old recovery password" : "Por favor, forneça a antiga senha de recuperação",
    "Please provide a new recovery password" : "Por favor, forneça a nova senha de recuperação",
    "Please repeat the new recovery password" : "Por favor, repita a nova senha de recuperação",
    "Password successfully changed." : "Senha alterada com sucesso.",
    "Could not change the password. Maybe the old password was not correct." : "Não foi possível alterar a senha. Talvez a senha antiga não estava correta.",
    "Recovery Key disabled" : "Recuperação de chave desativada",
    "Recovery Key enabled" : "Recuperar Chave habilitada",
    "Could not enable the recovery key, please try again or contact your administrator" : "Não foi possível habilitar a chave recuperada, por favor tente novamente ou entre em contato com seu administrador",
    "Could not update the private key password." : "Não foi possível atualizar a senha da chave privada.",
    "The old password was not correct, please try again." : "A senha antiga não estava correta, por favor, tente novamente.",
    "The current log-in password was not correct, please try again." : "A senha atual do log-in não estava correta, por favor, tente novamente.",
    "Private key password successfully updated." : "Senha de chave privada atualizada com sucesso.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "Você precisa migrar suas chaves de criptografia a partir da antiga criptografia (ownCloud <= 8,0) para a nova. Por favor, execute 'occ encryption:migrate' ou contate o seu administrador",
    "Invalid private key for Encryption App. Please update your private key password in your personal settings to recover access to your encrypted files." : "Chave do App de Criptografia é inválida. Por favor, atualize sua senha de chave privada em suas configurações pessoais para recuperar o acesso a seus arquivos criptografados.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "Criptografia do App está habilitada mas suas chaves não foram inicializadas. Por favor, desconecte-se e autentique-se novamente.",
    "Encryption App is enabled and ready" : "Aplicativo de criptografia está ativado e pronto",
    "Bad Signature" : "Assinatura Ruim",
    "Missing Signature" : "Faltando Assinatura",
    "one-time password for server-side-encryption" : "senha de uso único para criptografia-lado-servidor",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Este arquivo não pode ser decriptado, provavelmente este é um arquivo compartilhado. Por favor peça ao dono do arquivo para compartilha-lo com você.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Não é possível ler este arquivo, provavelmente este é um arquivo compartilhado. Por favor, pergunte o dono do arquivo para recompartilhar o arquivo com você.",
    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'ownCloud basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n" : "Olá,\n\nO administrador habilitou criptografia-lado-servidor. Os seus arquivos foram criptografados usando a senha '%s'.\n\nPor favor faça o login para a interface da Web, vá para a seção 'ownCloud módulo de criptografia básico' das suas definições pessoais e atualize sua senha de criptografia, inserindo esta senha no campo 'senha antiga de log-in' e sua atual senha-de-login.\n\n",
    "The share will expire on %s." : "O compartilhamento irá expirar em %s.",
    "Cheers!" : "Saudações!",
    "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"ownCloud basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "Olá,<br><br>o administrador habilitou criptografia-lado-servidor. Os seus arquivos foram criptografados usando a senha <strong>%s</strong>.<br><br>Por favor faça o login para a interface da Web, vá para a seção 'ownCloud módulo de criptografia básico' das suas definições pessoais e atualize sua senha de criptografia, inserindo esta senha no campo 'senha antiga de log-in' e sua atual senha-de-login..<br><br>",
    "Default encryption module" : "Módulo de criptografia padrão",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "App de criptografia está ativado, mas as chaves não estão inicializadas, por favor log-out e faça login novamente",
    "Encryption type: Master Key" : "Tipo de criptografia: Chave Mestra",
    "Encryption type: User Specific Key" : "Tipo de criptografia: Chave específica do usuário",
    "Please select an encryption option" : "Selecione uma opção de criptografia",
    "Master Key" : "Chave Mestra",
    "User-specific key" : "Chave específica do usuário",
    "Permanently select this mode" : "Selecionar este modo permanentemente ",
    "Encrypt the home storage" : "Criptografar a pasta de armazenamento home",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Ativar essa opção de criptografia para todos os arquivos armazenados no armazenamento principal, caso contrário, apenas arquivos no armazenamento externo serão criptografados",
    "Enable recovery key" : "Habilitar recuperação de chave",
    "Disable recovery key" : "Dasabilitar chave de recuperação",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "A chave de recuperação é uma chave de encriptação extra que é utilizada para encriptar arquivos. Ela permite a recuperação de arquivos de um usuário esquecer sua senha.",
    "Recovery key password" : "Senha da chave de recuperação",
    "Repeat recovery key password" : "Repita senha da chave de recuperação",
    "Change recovery key password:" : "Mudar a senha da chave de recuperação:",
    "Old recovery key password" : "Senha da chave de recuperação antiga",
    "New recovery key password" : "Nova senha da chave de recuperação",
    "Repeat new recovery key password" : "Repita a nova senha da chave de recuperação",
    "Change Password" : "Trocar Senha",
    "ownCloud basic encryption module" : "Modo de criptografia básico ownCloud",
    "Your private key password no longer matches your log-in password." : "A sua senha de chave privada não corresponde a sua senha de login.",
    "Set your old private key password to your current log-in password:" : "Defina a sua antiga senha da chave privada para sua senha de login atual:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Se você não se lembra de sua antiga senha você pode pedir ao administrador que recupere seus arquivos.",
    "Old log-in password" : "Senha antiga de login",
    "Current log-in password" : "Senha de login atual",
    "Update Private Key Password" : "Atualizar Senha de Chave Privada",
    "Enable password recovery:" : "Habilitar recuperação de senha:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Habilitar essa opção vai permitir que você obtenha novamente acesso aos seus arquivos encriptados em caso de perda de senha",
    "Enabled" : "Habilitado",
    "Disabled" : "Desabilitado"
},
"nplurals=2; plural=(n > 1);");
